**Example 1: 创建临时实例**



Input: 

```
tccli mariadb CreateTmpInstances --cli-unfold-argument  \
    --RollbackTime '2019-04-06 12:31:10' \
    --InstanceIds tdsql-arryr5nt
```

Output: 
```
{
    "Response": {
        "FlowId": 167,
        "RequestId": "64c3a7d3-cc27-45f7-9dff-7f950f9b5791"
    }
}
```

